@@ -7,7 +7,7 @@ import re
 from django.http import QueryDict
 from django.utils.unittest import expectedFailure
 
-__version__ = '0.1.1'
+__version__ = '0.1.2'
 
 safe_chars = re.compile(r'[\W_]', re.MULTILINE)
 
@@ -20,8 +20,7 @@ def python_safe(s):
 
 
 class PreparedRequest(object):
-    def __init__(self, test_class, request_description):
-        self.test_class = test_class
+    def __init__(self, request_description):
         self.request_description = self.validate(request_description)
 
     def __call__(self, test_case_instance):
@@ -29,11 +28,15 @@ class PreparedRequest(object):
         response = self.make_request(test_case_instance.client)
         self.expect_status(test_case_instance, response)
         self.expect_header(test_case_instance, response)
+        # TODO: Not yet implemented
         # self.expect_context()
         # self.expect()
 
     def validate(self, request_description):
         ret = request_description
+        ret['login as'] = (json.loads(ret['login as'])
+                           if ret['login as'] else {})
+        ret['url'] = ret['url']
         ret['method'] = ret['method'].lower()
         ret['querystring'] = (json.loads(ret['querystring'])
                               if ret['querystring'] else {})
@@ -45,11 +48,17 @@ class PreparedRequest(object):
         return ret
 
     def make_request(self, client):
+        if self.request_description['login as']:
+            client.login(**self.request_description['login as'])
+
         url = self.get_url()
         if self.request_description['method'] == 'get':
             response = client.get(url)
         elif self.request_description['method'] == 'post':
             response = client.post(url, self.request_description['post body'])
+
+        if self.request_description['login as']:
+            client.logout()
         return response
 
     def get_url(self):
@@ -76,8 +85,7 @@ class PreparedRequest(object):
 
 
 class PreparedTest(object):
-    def __init__(self, test_class, row_num, rows_for_test):
-        self.test_class = test_class
+    def __init__(self, row_num, rows_for_test):
         self.row_num = row_num
         self.rows_for_test = rows_for_test
 
@@ -96,8 +104,7 @@ class PreparedTest(object):
     def make_prepared_requests(self):
         prepared_requests = []
         for request_description in self.rows_for_test:
-            prepared_request = PreparedRequest(self.test_class,
-                                               request_description)
+            prepared_request = PreparedRequest(request_description)
             prepared_requests.append(prepared_request)
         return prepared_requests
 
@@ -135,7 +142,7 @@ def csv_to_tests(csv_path, test_class):
     with open(csv_path, 'rU') as f:
         reader = csv.DictReader(f)
         for row_num, rows_for_test in group_by_tests(reader):
-            prepared_test = PreparedTest(test_class, row_num, rows_for_test)
+            prepared_test = PreparedTest(row_num, rows_for_test)
             prepared_tests.append(prepared_test)
 
     return prepared_tests
